(count-snaps env)Returns the number of snapshots in environment.
Returns the number of snapshots in environment.
(get-all-instances)(get-all-instances environment)(get-all-instances environment region)Returns a list of all instances in a given region and environment.
Returns a list of all instances in a given region and environment.
(get-all-snapshots)(get-all-snapshots env)Returns a list of an account's active snapshots
Returns a list of an account's active snapshots
(get-by-role role)(get-by-role role environment)(get-by-role role environment region)Returns search results of ec2 instances by role tag.
Returns search results of ec2 instances by role tag.
(get-ip search-results)Returns a list of private ip addresses from search results.
Returns a list of private ip addresses from search results.
(search-ec2 filters)(search-ec2 filters environment)(search-ec2 filters environment region)Returns a list of ec2 instances given a list of filters.
Returns a list of ec2 instances given a list of filters.
(search-eni filters)(search-eni filters environment)(search-eni filters environment region)Returns for enis with given a list of filters.
Returns for enis with given a list of filters.
(search-snapshots filters)(search-snapshots filters environment)(search-snapshots filters environment region)Returns a list of ebs snapshots given a list of filters.
Returns a list of ebs snapshots given a list of filters.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |